==> eslint-config-staticdeploy-1.0.5.tgz: package/index.js <==
module.exports = {
    "parserOptions": {
        "ecmaVersion": 6
    },
    "env": {
        "browser": true,
        "mocha": true,
        "node": true
    },
    "rules": {
        // Possible errors
        "no-cond-assign": [2],
        "no-console": [0],
        "no-constant-condition": [2],
        "no-control-regex": [2],
        "no-debugger": [2],
        "no-dupe-args": [2],
        "no-dupe-keys": [2],
        "no-duplicate-case": [2],
        "no-empty-character-class": [2],
        "no-empty": [2],
        "no-ex-assign": [2],
        "no-extra-boolean-cast": [2],
        "no-extra-parens": [0],
        "no-extra-semi": [2],
        "no-func-assign": [2],
        "no-inner-declarations": [2],
        "no-invalid-regexp": [2],
        "no-irregular-whitespace": [2],
        "no-obj-calls": [2],
        "no-prototype-builtins": [0],
        "no-regex-spaces": [2],
        "no-sparse-arrays": [2],
        "no-template-curly-in-string": [0],
        "no-unexpected-multiline": [2],
        "no-unreachable": [2],
        "no-unsafe-finally": [2],
        "no-unsafe-negation": [0],
        "use-isnan": [2],
        "valid-jsdoc": [0],
        "valid-typeof": [2],
        // Best practices
        "accessor-pairs": [0],
        "array-callback-return": [2],
        "block-scoped-var": [2],
        "class-methods-use-this": [2],
        "complexity": [0],
        "consistent-return": [2],
        "curly": [2],
        "default-case": [2],
        "dot-location": [2, "property"],
        "dot-notation": [0],
        "eqeqeq": [2],
        "guard-for-in": [2],
        "no-alert": [2],
        "no-caller": [2],
        "no-case-declarations": [2],
        "no-div-regex": [0],
        "no-else-return": [0],
        "no-empty-function": [2],
        "no-empty-pattern": [2],
        "no-eq-null": [2],
        "no-eval": [2],
        "no-extend-native": [2],
        "no-extra-bind": [2],
        "no-extra-label": [2],
        "no-fallthrough": [2],
        "no-floating-decimal": [2],
        "no-global-assign": [2],
        "no-implicit-coercion": [2, {"allow": ["!!"]}],
        "no-implicit-globals": [2],
        "no-implied-eval": [2],
        "no-invalid-this": [2],
        "no-iterator": [2],
        "no-labels": [2],
        "no-lone-blocks": [2],
        "no-loop-func": [2],
        "no-magic-numbers": [0],
        "no-multi-spaces": [2],
        "no-multi-str": [2],
        "no-new-func": [2],
        "no-new-wrappers": [2],
        "no-new": [2],
        "no-octal-escape": [2],
        "no-octal": [2],
        "no-param-reassign": [2],
        "no-proto": [2],
        "no-redeclare": [2],
        "no-return-assign": [2],
        "no-script-url": [2],
        "no-self-assign": [2],
        "no-self-compare": [2],
        "no-sequences": [2],
        "no-throw-literal": [2],
        "no-unmodified-loop-condition": [2],
        "no-unused-expressions": [2],
        "no-unused-labels": [2],
        "no-useless-call": [2],
        "no-useless-concat": [2],
        "no-useless-escape": [2],
        "no-void": [2],
        "no-warning-comments": [0],
        "no-with": [2],
        "radix": [2],
        "vars-on-top": [0],
        "wrap-iife": [2, "inside"],
        "yoda": [2],
        // Strict mode
        "strict": [0],
        // Variables
        "init-declarations": [0],
        "no-catch-shadow": [2],
        "no-delete-var": [2],
        "no-label-var": [2],
        "no-restricted-globals": [2],
        "no-shadow-restricted-names": [2],
        "no-shadow": [2],
        "no-undef-init": [0],
        "no-undef": [2],
        "no-undefined": [2],
        "no-unused-vars": [2],
        "no-use-before-define": [2],
        // Node.js and CommonJS
        "callback-return": [2],
        "global-require": [0],
        "handle-callback-err": [2],
        "no-mixed-requires": [0],
        "no-new-require": [2],
        "no-path-concat": [2],
        "no-process-env": [0],
        "no-process-exit": [0],
        "no-restricted-modules": [0],
        "no-restricted-properties": [0],
        "no-sync": [0],
        // Stylistic issues
        "array-bracket-spacing": [2],
        "block-spacing": [0],
        "brace-style": [2],
        "camelcase": [2],
        "comma-dangle": [2],
        "comma-spacing": [2],
        "comma-style": [2],
        "computed-property-spacing": [2],
        "consistent-this": [2],
        "eol-last": [2],
        "func-call-spacing": [2],
        "func-names": [2],
        "func-style": [0],
        "id-blacklist": [0],
        "id-length": [0],
        "id-match": [0],
        "indent": [2],
        "jsx-quotes": [2, "prefer-double"],
        "key-spacing": [2],
        "keyword-spacing": [2],
        "line-comment-position": [2],
        "linebreak-style": [2],
        "lines-around-comment": [0],
        "lines-around-directive": [0],
        "max-depth": [2],
        "max-len": [2],
        "max-lines": [2],
        "max-nested-callbacks": [2],
        "max-params": [0],
        "max-statements-per-line": [2],
        "max-statements": [0],
        "multiline-ternary": [0],
        "new-cap": [2],
        "new-parens": [2],
        "newline-after-var": [0],
        "newline-before-return": [0],
        "newline-per-chained-call": [0],
        "no-array-constructor": [2],
        "no-bitwise": [2],
        "no-continue": [2],
        "no-inline-comments": [2],
        "no-lonely-if": [2],
        "no-mixed-operators": [2],
        "no-mixed-spaces-and-tabs": [2],
        "no-multiple-empty-lines": [2],
        "no-negated-condition": [0],
        "no-nested-ternary": [0],
        "no-new-object": [2],
        "no-plusplus": [0],
        "no-restricted-syntax": [0],
        "no-tabs": [2],
        "no-ternary": [0],
        "no-trailing-spaces": [2],
        "no-underscore-dangle": [2],
        "no-unneeded-ternary": [2],
        "no-whitespace-before-property": [2],
        "object-curly-newline": [2],
        "object-curly-spacing": [2],
        "object-property-newline": [2, { "allowMultiplePropertiesPerLine": true }],
        "one-var-declaration-per-line": [2],
        "one-var": [2, "never"],
        "operator-assignment": [2],
        "operator-linebreak": [2],
        "padded-blocks": [0],
        "quote-props": [2, "consistent-as-needed"],
        "quotes": [2],
        "require-jsdoc": [0],
        "semi-spacing": [0],
        "semi": [2],
        "sort-keys": [0],
        "sort-vars": [0],
        "space-before-blocks": [0],
        "space-before-function-paren": [2],
        "space-in-parens": [2],
        "space-infix-ops": [2],
        "space-unary-ops": [2],
        "spaced-comment": [2],
        "unicode-bom": [2],
        "wrap-regex": [0],
        // es6
        "arrow-body-style": [0],
        "arrow-parens": [2, "as-needed"],
        "arrow-spacing": [2],
        "constructor-super": [2],
        "generator-star-spacing": [2],
        "no-class-assign": [2],
        "no-confusing-arrow": [2, {"allowParens": true}],
        "no-const-assign": [2],
        "no-dupe-class-members": [2],
        "no-duplicate-imports": [2],
        "no-new-symbol": [2],
        "no-restricted-imports": [0],
        "no-this-before-super": [2],
        "no-useless-computed-key": [2],
        "no-useless-constructor": [2],
        "no-useless-rename": [2],
        "no-var": [0],
        "object-shorthand": [2, "consistent-as-needed"],
        "prefer-arrow-callback": [2],
        "prefer-const": [2],
        "prefer-numeric-literals": [0],
        "prefer-reflect": [0],
        "prefer-rest-params": [0],
        "prefer-spread": [0],
        "prefer-template": [2],
        "require-yield": [2],
        "rest-spread-spacing": [2],
        "sort-imports": [0],
        "symbol-description": [0],
        "template-curly-spacing": [2],
        "yield-star-spacing": [2]
    }
};

==> eslint-config-staticdeploy-2.0.1.tgz: package/index.js <==
module.exports = {
    "parserOptions": {
        "ecmaVersion": 6
    },
    "env": {
        "browser": true,
        "mocha": true,
        "node": true
    },
    "rules": {
        // Possible errors
        "no-cond-assign": [2],
        "no-console": [0],
        "no-constant-condition": [2],
        "no-control-regex": [2],
        "no-debugger": [2],
        "no-dupe-args": [2],
        "no-dupe-keys": [2],
        "no-duplicate-case": [2],
        "no-empty-character-class": [2],
        "no-empty": [2],
        "no-ex-assign": [2],
        "no-extra-boolean-cast": [2],
        "no-extra-parens": [0],
        "no-extra-semi": [2],
        "no-func-assign": [2],
        "no-inner-declarations": [2],
        "no-invalid-regexp": [2],
        "no-irregular-whitespace": [2],
        "no-obj-calls": [2],
        "no-prototype-builtins": [0],
        "no-regex-spaces": [2],
        "no-sparse-arrays": [2],
        "no-template-curly-in-string": [0],
        "no-unexpected-multiline": [2],
        "no-unreachable": [2],
        "no-unsafe-finally": [2],
        "no-unsafe-negation": [0],
        "use-isnan": [2],
        "valid-jsdoc": [0],
        "valid-typeof": [2],
        // Best practices
        "accessor-pairs": [0],
        "array-callback-return": [2],
        "block-scoped-var": [2],
        "class-methods-use-this": [0],
        "complexity": [0],
        "consistent-return": [2],
        "curly": [2],
        "default-case": [2],
        "dot-location": [2, "property"],
        "dot-notation": [0],
        "eqeqeq": [2],
        "guard-for-in": [2],
        "no-alert": [2],
        "no-caller": [2],
        "no-case-declarations": [2],
        "no-div-regex": [0],
        "no-else-return": [0],
        "no-empty-function": [2],
        "no-empty-pattern": [2],
        "no-eq-null": [2],
        "no-eval": [2],
        "no-extend-native": [2],
        "no-extra-bind": [2],
        "no-extra-label": [2],
        "no-fallthrough": [2],
        "no-floating-decimal": [2],
        "no-global-assign": [2],
        "no-implicit-coercion": [2, {"allow": ["!!"]}],
        "no-implicit-globals": [2],
        "no-implied-eval": [2],
        "no-invalid-this": [2],
        "no-iterator": [2],
        "no-labels": [2],
        "no-lone-blocks": [2],
        "no-loop-func": [2],
        "no-magic-numbers": [0],
        "no-multi-spaces": [2],
        "no-multi-str": [2],
        "no-new-func": [2],
        "no-new-wrappers": [2],
        "no-new": [2],
        "no-octal-escape": [2],
        "no-octal": [2],
        "no-param-reassign": [2],
        "no-proto": [2],
        "no-redeclare": [2],
        "no-return-assign": [2],
        "no-script-url": [2],
        "no-self-assign": [2],
        "no-self-compare": [2],
        "no-sequences": [2],
        "no-throw-literal": [2],
        "no-unmodified-loop-condition": [2],
        "no-unused-expressions": [2],
        "no-unused-labels": [2],
        "no-useless-call": [2],
        "no-useless-concat": [2],
        "no-useless-escape": [2],
        "no-void": [2],
        "no-warning-comments": [0],
        "no-with": [2],
        "radix": [2],
        "vars-on-top": [0],
        "wrap-iife": [2, "inside"],
        "yoda": [2],
        // Strict mode
        "strict": [0],
        // Variables
        "init-declarations": [0],
        "no-catch-shadow": [2],
        "no-delete-var": [2],
        "no-label-var": [2],
        "no-restricted-globals": [2],
        "no-shadow-restricted-names": [2],
        "no-shadow": [2],
        "no-undef-init": [0],
        "no-undef": [2],
        "no-undefined": [2],
        "no-unused-vars": [2],
        "no-use-before-define": [2],
        // Node.js and CommonJS
        "callback-return": [2],
        "global-require": [0],
        "handle-callback-err": [2],
        "no-mixed-requires": [0],
        "no-new-require": [2],
        "no-path-concat": [2],
        "no-process-env": [0],
        "no-process-exit": [0],
        "no-restricted-modules": [0],
        "no-restricted-properties": [0],
        "no-sync": [0],
        // Stylistic issues
        "array-bracket-spacing": [2],
        "block-spacing": [0],
        "brace-style": [2],
        "camelcase": [2],
        "comma-dangle": [2],
        "comma-spacing": [2],
        "comma-style": [2],
        "computed-property-spacing": [2],
        "consistent-this": [2],
        "eol-last": [2],
        "func-call-spacing": [2],
        "func-names": [2],
        "func-style": [0],
        "id-blacklist": [0],
        "id-length": [0],
        "id-match": [0],
        "indent": [2],
        "jsx-quotes": [2, "prefer-double"],
        "key-spacing": [2],
        "keyword-spacing": [2],
        "line-comment-position": [2],
        "linebreak-style": [2],
        "lines-around-comment": [0],
        "lines-around-directive": [0],
        "max-depth": [2],
        "max-len": [0],
        "max-lines": [2],
        "max-nested-callbacks": [2],
        "max-params": [0],
        "max-statements-per-line": [2],
        "max-statements": [0],
        "multiline-ternary": [0],
        "new-cap": [2],
        "new-parens": [2],
        "newline-after-var": [0],
        "newline-before-return": [0],
        "newline-per-chained-call": [0],
        "no-array-constructor": [2],
        "no-bitwise": [2],
        "no-continue": [2],
        "no-inline-comments": [2],
        "no-lonely-if": [2],
        "no-mixed-operators": [2],
        "no-mixed-spaces-and-tabs": [2],
        "no-multiple-empty-lines": [2],
        "no-negated-condition": [0],
        "no-nested-ternary": [0],
        "no-new-object": [2],
        "no-plusplus": [0],
        "no-restricted-syntax": [0],
        "no-tabs": [2],
        "no-ternary": [0],
        "no-trailing-spaces": [2],
        "no-underscore-dangle": [2],
        "no-unneeded-ternary": [2],
        "no-whitespace-before-property": [2],
        "object-curly-newline": [0],
        "object-curly-spacing": [2],
        "object-property-newline": [2, { "allowMultiplePropertiesPerLine": true }],
        "one-var-declaration-per-line": [2],
        "one-var": [2, "never"],
        "operator-assignment": [2],
        "operator-linebreak": [2],
        "padded-blocks": [0],
        "quote-props": [2, "consistent"],
        "quotes": [2],
        "require-jsdoc": [0],
        "semi-spacing": [0],
        "semi": [2],
        "sort-keys": [0],
        "sort-vars": [0],
        "space-before-blocks": [0],
        "space-before-function-paren": [2],
        "space-in-parens": [2],
        "space-infix-ops": [2],
        "space-unary-ops": [2],
        "spaced-comment": [2],
        "unicode-bom": [2],
        "wrap-regex": [0],
        // es6
        "arrow-body-style": [0],
        "arrow-parens": [2, "as-needed"],
        "arrow-spacing": [2],
        "constructor-super": [2],
        "generator-star-spacing": [2],
        "no-class-assign": [2],
        "no-confusing-arrow": [2, {"allowParens": true}],
        "no-const-assign": [2],
        "no-dupe-class-members": [2],
        "no-duplicate-imports": [2],
        "no-new-symbol": [2],
        "no-restricted-imports": [0],
        "no-this-before-super": [2],
        "no-useless-computed-key": [2],
        "no-useless-constructor": [2],
        "no-useless-rename": [2],
        "no-var": [0],
        "object-shorthand": [2, "consistent"],
        "prefer-arrow-callback": [2],
        "prefer-const": [2],
        "prefer-numeric-literals": [0],
        "prefer-reflect": [0],
        "prefer-rest-params": [0],
        "prefer-spread": [0],
        "prefer-template": [2],
        "require-yield": [2],
        "rest-spread-spacing": [2],
        "sort-imports": [0],
        "symbol-description": [0],
        "template-curly-spacing": [2],
        "yield-star-spacing": [2]
    }
};
